@@ -144,6 +144,11 @@ def log(a: Numeric):
     return tf.math.log(a)
 
 
+@dispatch
+def log1p(a: Numeric):
+    return tf.math.log1p(a)
+
+
 @dispatch
 def sin(a: Numeric):
     return tf.sin(a)
@@ -189,6 +194,11 @@ def erf(a: Numeric):
     return tf.math.erf(a)
 
 
+@dispatch
+def softplus(a: TFNumeric):
+    return tf.math.softplus(a)
+
+
 @dispatch
 def add(a: Numeric, b: Numeric):
     return tf.add(a, b)
