@@ -72,3 +72,24 @@ def choice(state: TorchRandomState, a: TorchNumeric, n: Int):
 @dispatch
 def choice(a: TorchNumeric, n: Int):
     return choice(global_random_state(a), a, n)[1]
+
+
+@dispatch
+def randint(
+    state: TorchRandomState, dtype: TorchDType, *shape: Int, lower: Int = 0, upper: Int
+):
+    dtype = B.dtype_int(dtype)
+    return state, torch.randint(
+        lower,
+        upper,
+        shape,
+        dtype=dtype,
+        device=B.ActiveDevice.active_name,
+        generator=state,
+    )
+
+
+@dispatch
+def randint(dtype: TorchDType, *shape: Int, lower: Int = 0, upper):
+    state = global_random_state(dtype)
+    return randint(state, dtype, *shape, lower=lower, upper=upper)[1]
